# Preferences persistence

Persistence utilities for `wordpress/preferences`.

Includes a persistence layer that saves data to WordPress user meta via the REST API. If for any reason data cannot be saved to the database, this persistence layer also uses local storage as a fallback.

## Installation

Install the module

```bash
npm install @wordpress/preferences-persistence --save
```

_This package assumes that your code will run in an **ES2015+** environment. If you're using an environment that has limited or no support for such language features and APIs, you should include [the polyfill shipped in `@wordpress/babel-preset-default`](https://github.com/WordPress/gutenberg/tree/HEAD/packages/babel-preset-default#polyfill) in your code._

## Usage

Call the `create` function to create a persistence layer.

```js
const persistenceLayer = create();
```

Next, configure the preferences package to use this persistence layer:

```js
wp.data( 'core/preferences' ).setPersistenceLayer( persistenceLayer );
```

## Reference

<!-- START TOKEN(Autogenerated Docs|src/index.js) -->

### create

Creates a persistence layer that stores data in WordPress user meta via the
REST API.

_Parameters_

-   _options_ `Object`:
-   _options.preloadedData_ `?Object`: Any persisted preferences data that should be preloaded. When set, the persistence layer will avoid fetching data from the REST API.
-   _options.localStorageRestoreKey_ `?string`: The key to use for restoring the localStorage backup, used when the persistence layer calls `localStorage.getItem` or `localStorage.setItem`.
-   _options.requestDebounceMS_ `?number`: Debounce requests to the API so that they only occur at minimum every `requestDebounceMS` milliseconds, and don't swamp the server. Defaults to 2500ms.

_Returns_

-   `Object`: A persistence layer for WordPress user meta.

<!-- END TOKEN(Autogenerated Docs|src/index.js) -->

## Contributing to this package

This is an individual package that's part of the Gutenberg project. The project is organized as a monorepo. It's made up of multiple self-contained software packages, each with a specific purpose. The packages in this monorepo are published to [npm](https://www.npmjs.com/) and used by [WordPress](https://make.wordpress.org/core/) as well as other software projects.

To find out more about contributing to this package or Gutenberg as a whole, please read the project's main [contributor guide](https://github.com/WordPress/gutenberg/tree/HEAD/CONTRIBUTING.md).

<br /><br /><p align="center"><img src="https://s.w.org/style/images/codeispoetry.png?1" alt="Code is Poetry." /></p>
